==> gax-0.12.0-sources.jar: com/google/api/gax/batching/BatchingThreshold.java <==
/*
 * Copyright 2016, Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.google.api.gax.batching;

/**
 * The interface representing a threshold to be used in ThresholdBatcher. Thresholds do not need to
 * be thread-safe if they are only used inside ThresholdBatcher.
 */
public interface BatchingThreshold<E> {

  /**
   * Presents the element to the threshold for the attribute of interest to be accumulated.
   *
   * Any calls into this function from ThresholdBatcher will be under a lock.
   */
  void accumulate(E e);

  /**
   * Any calls into this function from ThresholdBatcher will be under a lock.
   *
   * @return whether the threshold has been reached.
   */
  boolean isThresholdReached();

  /**
   * Make a copy of this threshold but with the accumulated value zeroed.
   *
   * Any calls into this function from ThresholdBatcher will be under a lock.
   */
  BatchingThreshold<E> copyWithZeroedValue();
}

==> gax-1.5.0-sources.jar: com/google/api/gax/batching/BatchingThreshold.java <==
/*
 * Copyright 2016, Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.google.api.gax.batching;

import com.google.api.core.BetaApi;

/**
 * The interface representing a threshold to be used in ThresholdBatcher. Thresholds do not need to
 * be thread-safe if they are only used inside ThresholdBatcher.
 */
@BetaApi
public interface BatchingThreshold<E> {

  /**
   * Presents the element to the threshold for the attribute of interest to be accumulated.
   *
   * <p>Any calls into this function from ThresholdBatcher will be under a lock.
   */
  void accumulate(E e);

  /**
   * Any calls into this function from ThresholdBatcher will be under a lock.
   *
   * @return whether the threshold has been reached.
   */
  boolean isThresholdReached();

  /**
   * Make a copy of this threshold but with the accumulated value zeroed.
   *
   * <p>Any calls into this function from ThresholdBatcher will be under a lock.
   */
  BatchingThreshold<E> copyWithZeroedValue();
}
